<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","");
define("_FYOURNAME","ͤس:");
define("_FYOUREMAIL","س:");
define("_FFRIENDNAME","͹س:");
define("_FFRIENDEMAIL","͹س:");
define("_HELLO","ʴ");
define("_YOURFRIEND","س");
define("_RECOMMEND","йӺ͡");
define("_INTSITE","纷ʹ:");
define("_OURSITE","Ԩó红ͧ");
define("_INTSENT","ʹеͧ觶֧س");
define("_FSITENAME"," :");
define("_FSITEURL"," URL:");
define("_FREFERENCE","Ţͧ䫵١ѧ");
define("_THANKSREC","͢ͺسй!");

?>